.. _release-0-9-0:

0.9.0
=====

Bokeh ``0.9.9`` (May 2015) provides sophisticated interactions in static plots
using a new Callback Action, a complete rewrite of the User guide and big
BokehJS refactoring switching to use browserify.

* Callback Action, serverless interactivity in static plots
* Hover inspection along lines
* Client side LOD downsampling for interactive tools
* Full User guide rewrite
* Reduce BokehJS boilerplate and switch to use browserify
* Several example bugfixes
